Editor Test

Automated Test - all check boxes should be checked
Focus: Value: Change: Blur: Disabled:

# Editor + Plugins Test

## No plugins, initially empty

## Created from div

lbl:

This instance is created from a div directly with default toolbar and plugins

The following HTML should appear as source: <INPUT TYPE="IMAGE" SRC="javascript:alert('no scripting attacks')">
lbl:

## Created from div, auto-expanding

### label for editor:

Extra text

This editor is created from a div with AlwaysShowToolbar plugin (do not forget to set height="").

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

The following HTML should appear as source: <INPUT TYPE="IMAGE" SRC="javascript:alert('no scripting attacks')">

### ..after

## Optional toolbar buttons

### blah entry

This instance includes optional toolbar buttons which pull in additional ui (dijit) code. Note the require() arguments to pull in the associated editor plugins to make this work.
This is serif.
This is sans-serif.
This is monospace.
This is cursive.
This is fantasy.

### ..after

## Plugins specified

### Another blah entry

This instance demos how to:

1. specify which plugins to load (see the plugins property): this instance loads FontChoice plugin, among others;
2. specify options for a plugin (see the last item in the plugins array)

### ..after

## Font sizing via style

Hello World!

## Checking pre-filter application

notdojo

## Checking editor starting with br

some stuff
some other stuff.

## Programmatic creation

This div will become an editor.
This div will become an auto-expanding editor.
This div will become a programmatic editor in addOnLoad with creation-defined default content.
This div will become a programmatic editor in addOnLoad with creation-defined and custom filters.